searchData={"items":[{"type":"module","title":"UUIDv7","doc":"A UUID v7 implementation and `Ecto.Type` for Elixir - based on Rust.\n\nThis library defers the UUID v7 implementation to the Rust create [UUID](https://crates.io/crates/uuid)\nusing an Erlang NIF. It includes an `Ecto.Type` to (auto-)generate version 7 UUIDs in `Ecto.Schema` and beyond.\n\nThanks to Rust, it is ~72% faster in generating version 7 UUIDs than the Elixir implementation\nof version 4 UUIDs by Ecto. See the benchmarks for more details.","ref":"UUIDv7.html"},{"type":"module","title":"Installation - UUIDv7","doc":"The package can be installed by adding `uuidv7` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:uuidv7, \"~> 0.2\"}]\nend\n```","ref":"UUIDv7.html#module-installation"},{"type":"module","title":"Usage - UUIDv7","doc":"In your database schema, change primary key attribute from `:binary_id` to `UUIDv7`:\n\n```elixir\ndef App.Schemas.User do\n  @primary_key {:id, UUIDv7, autogenerate: true}\nend\n```","ref":"UUIDv7.html#module-usage"},{"type":"module","title":"Benchmark - UUIDv7","doc":"Run `mix deps.get` and then `mix run scripts/bench.exs` to run the benchmark on your computer.\n\n```zsh\nOperating System: macOS\nCPU Information: Apple M2 Pro\nNumber of Available Cores: 10\nAvailable memory: 16 GB\nElixir 1.14.2\nErlang 25.1.2\n\nBenchmark suite executing with the following configuration:\nwarmup: 5 s\ntime: 10 s\nmemory time: 5 s\nreduction time: 0 ns\nparallel: 1\ninputs: none specified\nEstimated total run time: 1 min\n\nBenchmarking ecto (uuid v4) ...\nBenchmarking uniq (uuid v7) ...\nBenchmarking uuidv7 ...\n\nName                     ips        average  deviation         median         99th %\nuuidv7                1.75 M      570.22 ns  ±3940.19%         500 ns         667 ns\nuniq (uuid v7)        1.07 M      937.20 ns  ±1852.78%         916 ns        1000 ns\necto (uuid v4)        1.02 M      978.17 ns  ±1593.54%         958 ns        1042 ns\n\nComparison:\nuuidv7                1.75 M\nuniq (uuid v7)        1.07 M - 1.64x slower +366.98 ns\necto (uuid v4)        1.02 M - 1.72x slower +407.95 ns\n\nMemory usage statistics:\n\nName                   average  deviation         median         99th %\nuuidv7                   104 B     ±0.00%          104 B          104 B\nuniq (uuid v7)        214.00 B     ±2.47%          216 B          216 B\necto (uuid v4)        214.00 B     ±2.47%          216 B          216 B\n\nComparison:\nuuidv7                   104 B\nuniq (uuid v7)        214.00 B - 2.06x memory usage +110.00 B\necto (uuid v4)        214.00 B - 2.06x memory usage +110.00 B\n```","ref":"UUIDv7.html#module-benchmark"},{"type":"module","title":"Credits - UUIDv7","doc":"This library is based on the Rust library [UUID](https://crates.io/crates/uuid). Thank you!\n\nThe `Ecto.Type` is heavily borrowed from from [Ecto](https://github.com/elixir-ecto/ecto). Thanks!","ref":"UUIDv7.html#module-credits"},{"type":"function","title":"UUIDv7.cast/1","doc":"Casts to a UUID.","ref":"UUIDv7.html#cast/1"},{"type":"function","title":"UUIDv7.cast!/1","doc":"Same as `cast/1` but raises `Ecto.CastError` on invalid arguments.","ref":"UUIDv7.html#cast!/1"},{"type":"function","title":"UUIDv7.dump/1","doc":"Converts a string representing a UUID into a raw binary.","ref":"UUIDv7.html#dump/1"},{"type":"function","title":"UUIDv7.dump!/1","doc":"Same as `dump/1` but raises `Ecto.ArgumentError` on invalid arguments.","ref":"UUIDv7.html#dump!/1"},{"type":"function","title":"UUIDv7.embed_as/1","doc":"","ref":"UUIDv7.html#embed_as/1"},{"type":"function","title":"UUIDv7.equal?/2","doc":"","ref":"UUIDv7.html#equal?/2"},{"type":"function","title":"UUIDv7.generate/0","doc":"Generates a version 7 UUID.","ref":"UUIDv7.html#generate/0"},{"type":"function","title":"UUIDv7.generate/1","doc":"Generates a version 7 UUID based on the timestamp (ms).","ref":"UUIDv7.html#generate/1"},{"type":"function","title":"UUIDv7.generate_from_ms/1","doc":"Generates a version 7 UUID based on the timestamp (ms).","ref":"UUIDv7.html#generate_from_ms/1"},{"type":"function","title":"UUIDv7.load/1","doc":"Converts a binary UUID into a string.","ref":"UUIDv7.html#load/1"},{"type":"function","title":"UUIDv7.load!/1","doc":"Same as `load/1` but raises `Ecto.ArgumentError` on invalid arguments.","ref":"UUIDv7.html#load!/1"},{"type":"type","title":"UUIDv7.raw/0","doc":"A raw binary representation of a UUID.","ref":"UUIDv7.html#t:raw/0"},{"type":"type","title":"UUIDv7.t/0","doc":"A hex-encoded UUID string.","ref":"UUIDv7.html#t:t/0"},{"type":"module","title":"UUIDv7.Type","doc":"Ecto.Type implementation. Basically a copy of Ecto.UUID without the generators.","ref":"UUIDv7.Type.html"},{"type":"extras","title":"UUIDv7","doc":"# UUIDv7\n\nA UUID v7 implementation and `Ecto.Type` for Elixir - based on Rust.\n\nThis library defers the UUID v7 implementation to the Rust create [UUID](https://crates.io/crates/uuid)\nusing an Erlang NIF. It includes an `Ecto.Type` to (auto-)generate version 7 UUIDs in `Ecto.Schema` and beyond.\n\nThanks to Rust, it is ~72% faster in generating version 7 UUIDs than the Elixir implementation\nof version 4 UUIDs by Ecto. See the benchmarks for more details.","ref":"readme.html"},{"type":"extras","title":"Installation - UUIDv7","doc":"The package can be installed by adding `uuidv7` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [{:uuidv7, \"~> 0.2\"}]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - UUIDv7","doc":"In your database schema, change primary key attribute from `:binary_id` to `UUIDv7`:\n\n```elixir\ndef App.Schemas.User do\n  @primary_key {:id, UUIDv7, autogenerate: true}\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Benchmark - UUIDv7","doc":"Run `mix deps.get` and then `mix run scripts/bench.exs` to run the benchmark on your computer.\n\n```zsh\nOperating System: macOS\nCPU Information: Apple M2 Pro\nNumber of Available Cores: 10\nAvailable memory: 16 GB\nElixir 1.14.2\nErlang 25.1.2\n\nBenchmark suite executing with the following configuration:\nwarmup: 5 s\ntime: 10 s\nmemory time: 5 s\nreduction time: 0 ns\nparallel: 1\ninputs: none specified\nEstimated total run time: 1 min\n\nBenchmarking ecto (uuid v4) ...\nBenchmarking uniq (uuid v7) ...\nBenchmarking uuidv7 ...\n\nName                     ips        average  deviation         median         99th %\nuuidv7                1.75 M      570.22 ns  ±3940.19%         500 ns         667 ns\nuniq (uuid v7)        1.07 M      937.20 ns  ±1852.78%         916 ns        1000 ns\necto (uuid v4)        1.02 M      978.17 ns  ±1593.54%         958 ns        1042 ns\n\nComparison:\nuuidv7                1.75 M\nuniq (uuid v7)        1.07 M - 1.64x slower +366.98 ns\necto (uuid v4)        1.02 M - 1.72x slower +407.95 ns\n\nMemory usage statistics:\n\nName                   average  deviation         median         99th %\nuuidv7                   104 B     ±0.00%          104 B          104 B\nuniq (uuid v7)        214.00 B     ±2.47%          216 B          216 B\necto (uuid v4)        214.00 B     ±2.47%          216 B          216 B\n\nComparison:\nuuidv7                   104 B\nuniq (uuid v7)        214.00 B - 2.06x memory usage +110.00 B\necto (uuid v4)        214.00 B - 2.06x memory usage +110.00 B\n```","ref":"readme.html#benchmark"},{"type":"extras","title":"Credits - UUIDv7","doc":"This library is based on the Rust library [UUID](https://crates.io/crates/uuid). Thank you!\n\nThe `Ecto.Type` is heavily borrowed from from [Ecto](https://github.com/elixir-ecto/ecto). Thanks!","ref":"readme.html#credits"}],"content_type":"text/markdown"}